Index: src/crankshaft/arm64/lithium-codegen-arm64.cc |
diff --git a/src/crankshaft/arm64/lithium-codegen-arm64.cc b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
index 1d9c9071fc35aab155fd8dc6ca483694d19bea19..9fe4f5231a2b3a9cbb4f4e576f1481c2734bf35d 100644 |
--- a/src/crankshaft/arm64/lithium-codegen-arm64.cc |
+++ b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
@@ -594,10 +594,10 @@ void LCodeGen::DoPrologue(LPrologue* instr) { |
__ Push(x1, x10); |
__ CallRuntime(Runtime::kNewScriptContext); |
deopt_mode = Safepoint::kLazyDeopt; |
- } else if (slots <= FastNewContextStub::kMaximumSlots) { |
- FastNewContextStub stub(isolate(), slots); |
+ } else if (slots <= FastNewFunctionContextStub::kMaximumSlots) { |
+ FastNewFunctionContextStub stub(isolate(), slots); |
__ CallStub(&stub); |
// Result of FastNewContextStub is always in new space. |
need_write_barrier = false; |
} else { |
__ Push(x1); |
@@ -594,10 +594,10 @@ void LCodeGen::DoPrologue(LPrologue* instr) { |
__ CallStub(&stub); |
- // Result of FastNewContextStub is always in new space. |
+ // Result of FastNewFunctionContextStub is always in new space. |
need_write_barrier = false; |
} else { |